/*
 *
 *  Copyright (C) 2012 Open-Xchange, Inc. All rights reserved.
 *
 *  This program is proprietary software and licensed to you under Open-Xchange
 *  Inc's Software License Agreement.
 *
 *  In some countries OX, OX Open-Xchange, open-xchange and OXtender as well as
 *  the corresponding Logos OX Open-Xchange and OX are registered trademarks of
 *  the Open-Xchange, Inc. group of companies.
 *
 */

package com.openexchange.documentconverter;

/**
 * {@link BackendDescriptor}
 *
 * @author <a href="mailto:kai.ahrens@open-xchange.com">Kai Ahrens</a>
 */
public class BackendDescriptor {

    public BackendType type = BackendType.LIBO;
    public String installPath = null;
    public String userPath = null;
    public long maxVMemMB = -1;
    public int restartCount = 1;
    public String blacklistFile = null;
    public String whitelistFile = null;
    public int urlLinkLimit = -1;
    public String urlLinkProxy = null;
}
